## ----setup, include=FALSE-----------------------------------------------------
options(repos = c(CRAN = "https://cran.rstudio.com/"))


## ----eval=FALSE---------------------------------------------------------------
# if (!require("BiocManager", quietly = TRUE))
#     install.packages("BiocManager")
# 
# BiocManager::install("rhinotypeR")

## -----------------------------------------------------------------------------
library(rhinotypeR)

## ----eval=FALSE---------------------------------------------------------------
# getPrototypeSeqs("~/Desktop")

## -----------------------------------------------------------------------------
sequences <- Biostrings::readDNAStringSet(system.file("extdata", "input_aln.fasta", package="rhinotypeR"))

## -----------------------------------------------------------------------------
SNPeek(sequences)

## -----------------------------------------------------------------------------
distances <- pairwiseDistances(sequences, model = "p-distance", gapDeletion = TRUE)

## ----echo=FALSE---------------------------------------------------------------
distances[1:5, 1:7]

## -----------------------------------------------------------------------------
genotypes <- assignTypes(sequences, model = "p-distance", gapDeletion = TRUE, threshold = 0.105)

head(genotypes)


## -----------------------------------------------------------------------------
plotFrequency(genotypes)

## -----------------------------------------------------------------------------
plotDistances(distances)

## -----------------------------------------------------------------------------
# sub-sample 
sampled_distances <- distances[1:30,1:30]

plotTree(sampled_distances, hang = -1, cex = 0.6, main = "A simple tree", xlab = "", ylab = "Genetic distance")

## -----------------------------------------------------------------------------
sessionInfo()

